==> bit_ads_pakage_all-1.0.12.tar.gz: lib/webview.dart <==
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:url_launcher/url_launcher.dart';
import 'package:webview_flutter_x5/webview_flutter.dart';

import 'ads/model/admob_settings.dart';

class IntraWebView extends StatefulWidget {


 AdmobSettings? admobSettings;
  IntraWebView({Key? key, this.admobSettings}) : super(key: key);

  void init(AdmobSettings admobSettings) {
    admobSettings = admobSettings;
  }

  @override
  _IntraWebViewState createState() => _IntraWebViewState();
}

class _IntraWebViewState extends State<IntraWebView> {
  _launchURL(String url) async {
    if (await canLaunch(url)) {
      await launch(url);
    } else {
      throw 'Could not launch $url';
    }
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
        body: Stack(
      children: [
        WebView(
          gestureNavigationEnabled: true,
          navigationDelegate: (action) {
            Get.back();

            return _launchURL(action.url);
            // return NavigationDecision.navigate;
          },
          javascriptMode: JavascriptMode.unrestricted,
          initialUrl: '${widget.admobSettings!.customAds!.interstitialAdsUrl}',
        ),
        SizedBox(
          height: 10,
        ),
        Padding(
          padding: EdgeInsets.only(left: 20, right: 20, top: 45),
          child: Align(
              alignment: Alignment.topRight,
              child: InkWell(
                onTap: () {
                  Get.back();
                },
                child: Image(
                    image: AssetImage("assets/connecting/1.png"), height: 45),
              )),
        )
      ],
    ));
  }
}

==> bit_ads_pakage_all-1.0.14.tar.gz: lib/webview.dart <==
import 'package:bit_ads_pakage_all/ad_manager.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:url_launcher/url_launcher.dart';
import 'package:webview_flutter_x5/webview_flutter.dart';

import 'ads/model/admob_settings.dart';

class IntraWebView extends StatefulWidget {


 AdmobSettings? admobSettings;
  IntraWebView({Key? key, this.admobSettings}) : super(key: key);

  void init(AdmobSettings admobSettings) {
    admobSettings = admobSettings;
  }

  @override
  _IntraWebViewState createState() => _IntraWebViewState();
}

class _IntraWebViewState extends State<IntraWebView> {
  _launchURL(String url) async {
    if (await canLaunch(url)) {
      await launch(url);
    } else {
      throw 'Could not launch $url';
    }
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
        body: Stack(
      children: [
        WebView(
          gestureNavigationEnabled: true,
          navigationDelegate: (action) {
            Get.back();

            return _launchURL(action.url);
            // return NavigationDecision.navigate;
          },
          javascriptMode: JavascriptMode.unrestricted,
          initialUrl: '${AdsManager.webViewUrl}',
        ),
        SizedBox(
          height: 10,
        ),
        Padding(
          padding: EdgeInsets.only(left: 20, right: 20, top: 45),
          child: Align(
              alignment: Alignment.topRight,
              child: InkWell(
                onTap: () {
                  Get.back();
                },
                child: Image(
                    image: AssetImage("assets/connecting/1.png"), height: 45),
              )),
        )
      ],
    ));
  }
}
